package com.foreverwin.mesnac.anomaly.controller;


import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.foreverwin.mesnac.anomaly.model.AbnormalBill;
import com.foreverwin.mesnac.anomaly.service.AbnormalBillService;
import com.foreverwin.mesnac.common.helper.NextNumberHelper;
import com.foreverwin.mesnac.meapi.controller.WorkCenterController;
import com.foreverwin.mesnac.meapi.model.NcCode;
import com.foreverwin.mesnac.meapi.model.WorkCenter;
import com.foreverwin.mesnac.meapi.service.NcCodeService;
import com.foreverwin.modular.core.util.CommonMethods;
import com.foreverwin.modular.core.util.FrontPage;
import com.foreverwin.modular.core.util.R;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.HashMap;
import java.util.List;

/**
 *
 * @author robert
 * @since 2021-06-25
 */
@RestController
@RequestMapping("/Z-ABNORMAL-BILL")
public class AbnormalBillController {

    @Autowired
    public AbnormalBillService abnormalBillService;

    @Autowired
    public NcCodeService ncCodeService;

    @Autowired
    public WorkCenterController workCenterController;

    @Autowired
    public NextNumberHelper nextNumberHelper;

    /**
    * 根据id查询
    *
    * @param id 主键
    * @return
    */
    @ResponseBody
    @GetMapping("/{id:.+}")
    public R getAbnormalBillById(@PathVariable String id) {
        return R.ok( abnormalBillService.getById(id));
    }

    /**
     * 查询所有数据
     *
     * @return
     */
    @ResponseBody
    @GetMapping("")
    public R getAbnormalBillList(AbnormalBill abnormalBill){
        List<AbnormalBill> result;
        QueryWrapper<AbnormalBill> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(abnormalBill);
        result = abnormalBillService.list(queryWrapper);
        return R.ok(result);
    }

    /**
     * 分页查询数据
     *
     * @param frontPage  分页信息
     * @return
     */
    @ResponseBody
    @GetMapping("/page")
    public R page(FrontPage<AbnormalBill> frontPage, AbnormalBill abnormalBill){
        IPage result;
        QueryWrapper<AbnormalBill> queryWrapper = new QueryWrapper<>();
        queryWrapper.setEntity(abnormalBill);
        if (frontPage.getGlobalQuery() != null && !"".equals(frontPage.getGlobalQuery().trim())) {
            //TODO modify global query
            queryWrapper.lambda().and(wrapper -> wrapper
                .like(AbnormalBill::getHandle, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getSite, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getAbnormalNo, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getStatus, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getType, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getItemBo, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getSfc, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getWorkCenter, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getShopOrder, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getMessageType, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getResrce, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getNcCode, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getShutDown, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getResponseUser, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getPbDescription, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getNcQty, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getPbGrade, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getPbUser, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getPbQty, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getDiscover, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getInspecter, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getEntityLocation, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getReportFrom, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getObjectBo, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getPbPhotoshop, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getCancelCode, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getCancelReason, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getCancelUser, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getCreatedUser, frontPage.getGlobalQuery())
                .or().like(AbnormalBill::getModifiedUser, frontPage.getGlobalQuery())
    );
        }
        result = abnormalBillService.page(frontPage.getPagePlus(), queryWrapper);
        return R.ok(result);
    }

    /**
     * 新增
     * @param abnormalBill  传递的实体
     * @return  null 失败  实体成功
     */
    @PostMapping
    public R save(@RequestBody AbnormalBill abnormalBill) {
        return R.ok(abnormalBillService.save(abnormalBill));
    }

    /**
     * 修改
     * @param abnormalBill  传递的实体
     * @return  null 失败  实体成功
     */
    @PutMapping
    public R updateById(@RequestBody AbnormalBill abnormalBill) {
        return R.ok(abnormalBillService.updateById(abnormalBill));
    }

    /**
     * 根据id删除对象
     * @param id  实体ID
     * @return 0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.DELETE, value = "/{id:.+}")
    public R removeById(@PathVariable("id") String id){
        return R.ok(abnormalBillService.removeById(id));
    }

    /**
     * 批量删除对象
     * @param ids 实体集合ID
     * @return  0 失败  1 成功
     */
    @ResponseBody
    @RequestMapping(method = RequestMethod.POST, value = "/delete-batch")
    public R removeByIds(List<String> ids){
        return R.ok(abnormalBillService.removeByIds(ids));
    }

    @GetMapping("/init")
    public R init(String messageType){
        List<NcCode> ncByNG = ncCodeService.findNcByNG(messageType);
        WorkCenter workCenter = new WorkCenter();
        workCenter.setWcCategory("LEVEL4");
        R workCenterList = workCenterController.getWorkCenterList(workCenter);
        HashMap<String, Object> hashMap = new HashMap<>();
        hashMap.put("ncByNG",ncByNG);
        hashMap.put("workCenter",workCenterList);
        return R.ok(hashMap);
    }

    @GetMapping("/findAllUserByUserGroup")
    public R findAllUserByUserGroup(String site, String userGroups){
        return R.ok();
    }
    @GetMapping("/getNextNumber")
    public R getNextNumber(String numberType){
        String site = CommonMethods.getSite();
        List<String> nextNumber = nextNumberHelper.getNextNumber(site, numberType, 1, null);
        return R.ok(nextNumber.get(0));
    }
}